==> scandit-titanium-datacapture-core-6.16.2.tgz: modules/iphone/com.scandit.ti.datacapture.core/6.16.2/platform/ScanditCaptureCore.xcframework/ios-arm64_x86_64-simulator/ScanditCaptureCore.framework/Headers/SDCJSONValue.h <==
/*
 * This file is part of the Scandit Data Capture SDK
 *
 * Copyright (C) 2017- Scandit AG. All rights reserved.
 */

#import <UIKit/UIKit.h>

#import <ScanditCaptureCore/SDCBase.h>
#import <ScanditCaptureCore/SDCMeasureUnit.h>

@class SDCBrush;
@class SDCSizeWithUnitAndAspect;

NS_ASSUME_NONNULL_BEGIN

/**
 * Added in version 6.0.0
 *
 * JSON representation for use with the Scandit Data Capture SDK. It provides a lot of convenience functions for deserialization of base classes. It also tracks the usage of properties to be able to later report those that were not used for deserialization (potentially because they were misspelled or are outdated).
 */
NS_SWIFT_NAME(JSONValue)
SDC_EXPORTED_SYMBOL
@interface SDCJSONValue : NSObject

/**
 * Added in version 6.1.0
 *
 * Whether this JSON value was used during deserialization.
 */
@property (nonatomic, assign, getter=isUsed) BOOL used;
/**
 * Added in version 6.1.0
 *
 * The path from the root to this JSON value.
 */
@property (nonatomic, strong, readonly) NSString *absolutePath;

+ (instancetype)new NS_UNAVAILABLE;
- (instancetype)init NS_UNAVAILABLE;

/**
 * Added in version 6.1.0
 *
 * Returns a new JSON Value for the given json string. An exception is thrown if the string is not a valid JSON representation.
 */
+ (instancetype)JSONValueWithString:(nonnull NSString *)string;

/**
 * Added in version 6.1.0
 *
 * Returns the string representation of the JSON value.
 */
- (nonnull NSString *)jsonString;

/**
 * Added in version 6.1.0
 *
 * Returns the value as a boolean. An exception is thrown if the conversion is not possible.
 */
- (BOOL)asBOOL;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a boolean. An exception is thrown if this JSON Value is not an object, it does not contain a value for the given key or the value for the given key is not a boolean.
 */
- (BOOL)BOOLForKey:(nonnull NSString *)key;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a boolean. The default value is returned if there is no value for the given key. An exception is thrown if this JSON Value is not an object or the value for the given key is not a boolean.
 */
- (BOOL)BOOLForKey:(nonnull NSString *)key default:(BOOL)defaultValue;

/**
 * Added in version 6.1.0
 *
 * Returns the value as an integer. An exception is thrown if the conversion is not possible.
 */
- (NSInteger)asInteger;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as an integer. An exception is thrown if this JSON Value is not an object, it does not contain a value for the given key or the value for the given key is not an integer.
 */
- (NSInteger)integerForKey:(nonnull NSString *)key;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as an integer. The default value is returned if there is no value for the given key. An exception is thrown if this JSON Value is not an object or the value for the given key is not an integer.
 */
- (NSInteger)integerForKey:(nonnull NSString *)key default:(NSInteger)defaultValue;

/**
 * Added in version 6.1.0
 *
 * Returns the value as a float. An exception is thrown if the conversion is not possible.
 */
- (CGFloat)asCGFloat;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a float. An exception is thrown if this JSON Value is not an object, it does not contain a value for the given key or the value for the given key is not a float.
 */
- (CGFloat)CGFloatForKey:(nonnull NSString *)key;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a float. The default value is returned if there is no value for the given key. An exception is thrown if this JSON Value is not an object or the value for the given key is not a float.
 */
- (CGFloat)CGFloatForKey:(nonnull NSString *)key default:(CGFloat)defaultValue;

/**
 * Added in version 6.16.0
 *
 * Returns the current value as a value representing a NSTimeInterval.
 */
- (NSTimeInterval)asTimeinterval;
/**
 * Added in version 6.16.0
 *
 * Returns the value for the given key as a NSTimeInterval.
 */
- (NSTimeInterval)timeintervalForKey:(nonnull NSString *)key;

/**
 * Added in version 6.1.0
 *
 * Returns the value as a string. An exception is thrown if the conversion is not possible.
 */
- (nonnull NSString *)asString;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a string. An exception is thrown if this JSON Value is not an object, it does not contain a value for the given key or the value for the given key is not a string.
 */
- (nonnull NSString *)stringForKey:(nonnull NSString *)key;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a string. The default value is returned if there is no value for the given key. An exception is thrown if this JSON Value is not an object or the value for the given key is not a string.
 */
- (nonnull NSString *)stringForKey:(nonnull NSString *)key default:(nonnull NSString *)defaultValue;

/**
 * Added in version 6.1.0
 *
 * Returns the value as a color. An exception is thrown if the conversion is not possible.
 */
- (nonnull UIColor *)asColor;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a color. An exception is thrown if this JSON Value is not an object, it does not contain a value for the given key or the value for the given key is not a color.
 */
- (nonnull UIColor *)colorForKey:(nonnull NSString *)key;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a color. The default value is returned if there is no value for the given key. An exception is thrown if this JSON Value is not an object or the value for the given key is not a color.
 */
- (nonnull UIColor *)colorForKey:(nonnull NSString *)key default:(nonnull UIColor *)defaultValue;

/**
 * Added in version 6.1.0
 *
 * Returns the value as a SDCBrush. An exception is thrown if the conversion is not possible.
 */
- (nonnull SDCBrush *)asBrush;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a SDCBrush. An exception is thrown if this JSON Value is not an object, it does not contain a value for the given key or the value for the given key is not a SDCBrush.
 */
- (nonnull SDCBrush *)brushForKey:(nonnull NSString *)key;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a SDCBrush. The default value is returned if there is no value for the given key. An exception is thrown if this JSON Value is not an object or the value for the given key is not a SDCBrush.
 */
- (nullable SDCBrush *)brushForKey:(nonnull NSString *)key
                           default:(nullable SDCBrush *)defaultValue;

/**
 * Added in version 6.1.0
 *
 * Returns the value as a SDCFloatWithUnit. An exception is thrown if the conversion is not possible.
 */
- (SDCFloatWithUnit)asFloatWithUnit;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a SDCFloatWithUnit. An exception is thrown if this JSON Value is not an object, it does not contain a value for the given key or the value for the given key is not a SDCFloatWithUnit.
 */
- (SDCFloatWithUnit)floatWithUnitForKey:(nonnull NSString *)key;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a SDCFloatWithUnit. The default value is returned if there is no value for the given key. An exception is thrown if this JSON Value is not an object or the value for the given key is not a SDCFloatWithUnit.
 */
- (SDCFloatWithUnit)floatWithUnitForKey:(nonnull NSString *)key
                                default:(SDCFloatWithUnit)defaultValue;

/**
 * Added in version 6.1.0
 *
 * Returns the value as a SDCPointWithUnit. An exception is thrown if the conversion is not possible.
 */
- (SDCPointWithUnit)asPointWithUnit;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a SDCPointWithUnit. An exception is thrown if this JSON Value is not an object, it does not contain a value for the given key or the value for the given key is not a SDCPointWithUnit.
 */
- (SDCPointWithUnit)pointWithUnitForKey:(nonnull NSString *)key;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a SDCPointWithUnit. The default value is returned if there is no value for the given key. An exception is thrown if this JSON Value is not an object or the value for the given key is not a SDCPointWithUnit.
 */
- (SDCPointWithUnit)pointWithUnitForKey:(nonnull NSString *)key
                                default:(SDCPointWithUnit)defaultValue;

/**
 * Added in version 6.1.0
 *
 * Returns the value as a SDCMarginsWithUnit. An exception is thrown if the conversion is not possible.
 */
- (SDCMarginsWithUnit)asMarginsWithUnit;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a SDCMarginsWithUnit. An exception is thrown if this JSON Value is not an object, it does not contain a value for the given key or the value for the given key is not a SDCMarginsWithUnit.
 */
- (SDCMarginsWithUnit)marginsWithUnitForKey:(nonnull NSString *)key;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as a SDCMarginsWithUnit. The default value is returned if there is no value for the given key. An exception is thrown if this JSON Value is not an object or the value for the given key is not a SDCMarginsWithUnit.
 */
- (SDCMarginsWithUnit)marginsWithUnitForKey:(nonnull NSString *)key
                                    default:(SDCMarginsWithUnit)defaultValue;

/**
 * Added in version 6.1.0
 *
 * Returns the value if it is an array. An exception is thrown if the conversion is not possible.
 */
- (nonnull SDCJSONValue *)asArray;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as an array. An exception is thrown if this JSON Value is not an object, it does not contain a value for the given key or the value for the given key is not an array.
 */
- (nonnull SDCJSONValue *)arrayForKey:(nonnull NSString *)key;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as an array. The default value is returned if there is no value for the given key. An exception is thrown if this JSON Value is not an object or the value for the given key is not an array.
 */
- (nullable SDCJSONValue *)arrayForKey:(nonnull NSString *)key
                               default:(nullable SDCJSONValue *)defaultValue;
/**
 * Added in version 6.1.0
 *
 * The size of the array. An exception is thrown if this JSON value is not an array.
 */
- (NSUInteger)count;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given index. An exception is thrown if this JSON Value is not an array or the given index is out of bounds.
 */
- (nonnull SDCJSONValue *)JSONValueAtIndex:(NSUInteger)index;

/**
 * Added in version 6.1.0
 *
 * Returns the value if it is an object. An exception is thrown if the conversion is not possible.
 */
- (nonnull SDCJSONValue *)asObject;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as an object. An exception is thrown if this JSON Value is not an object, it does not contain a value for the given key or the value for the given key is not an object.
 */
- (nonnull SDCJSONValue *)objectForKey:(nonnull NSString *)key;
/**
 * Added in version 6.1.0
 *
 * Returns the value for the given key as an object. The default value is returned if there is no value for the given key. An exception is thrown if this JSON Value is not an object or the value for the given key is not an object.
 */
- (nullable SDCJSONValue *)objectForKey:(nonnull NSString *)key
                                default:(nullable SDCJSONValue *)defaultValue;
/**
 * Added in version 6.1.0
 *
 * Returns whether a value for the given key exists. An exception is thrown if this JSON Value is not an object.
 *
 * Added in version 6.1.0
 *
 * Returns the value for the given key. An exception is thrown if this JSON Value is not an object or it does not contain a value for the given key.
 */
- (BOOL)containsKey:(nonnull NSString *)key;
/**
 * Added in version 6.16.0
 *
 * Returns the keys of the current value if any.
 */
- (nonnull NSSet<NSString *> *)keys;

/**
 * Added in version 6.16.0
 *
 * Removes the given keys from the current value.
 */
- (void)removeKeys:(nonnull NSSet<NSString *> *)keysToRemove;

/**
 * Added in version 6.16.0
 *
 * Determines whether the current value is an object and contains an array with the given key.
 */
- (BOOL)containsArrayWithKey:(nonnull NSString *)key;
/**
 * Added in version 6.16.0
 *
 * Determines whether the current value is an object and contains an object with the given key.
 */
- (BOOL)containsObjectWithKey:(nonnull NSString *)key;
/**
 * Added in version 6.16.0
 *
 * Renames the given key to the target key name if the given key name is present.
 */
- (void)renameKey:(nonnull NSString *)originalKeyName
    targetKeyName:(nonnull NSString *)targetKeyName;

@end

NS_ASSUME_NONNULL_END

==> scandit-titanium-datacapture-core-6.28.0.tgz: modules/iphone/com.scandit.ti.datacapture.core/6.28.0/platform/ScanditCaptureCore.xcframework/ios-arm64_x86_64-simulator/ScanditCaptureCore.framework/Headers/SDCJSONValue.h <==
/*
 * This file is part of the Scandit Data Capture SDK
 *
 * Copyright (C) 2019- Scandit AG. All rights reserved.
 */

#import <UIKit/UIKit.h>

#import <ScanditCaptureCore/SDCBase.h>
#import <ScanditCaptureCore/SDCMeasureUnit.h>

@class SDCBrush;
@class SDCSizeWithUnitAndAspect;

NS_ASSUME_NONNULL_BEGIN

NS_SWIFT_NAME(JSONValue)
SDC_EXPORTED_SYMBOL
@interface SDCJSONValue : NSObject

@property (nonatomic, assign, getter=isUsed) BOOL used;
@property (nonatomic, strong, readonly) NSString *absolutePath;

+ (instancetype)new NS_UNAVAILABLE;
- (instancetype)init NS_UNAVAILABLE;

+ (instancetype)JSONValueWithString:(nonnull NSString *)string;

- (nonnull NSString *)jsonString;

- (BOOL)asBOOL;
- (BOOL)BOOLForKey:(nonnull NSString *)key;
- (BOOL)BOOLForKey:(nonnull NSString *)key default:(BOOL)defaultValue;

- (NSInteger)asInteger;
- (NSInteger)integerForKey:(nonnull NSString *)key;
- (NSInteger)integerForKey:(nonnull NSString *)key default:(NSInteger)defaultValue;

- (CGFloat)asCGFloat;
- (CGFloat)CGFloatForKey:(nonnull NSString *)key;
- (CGFloat)CGFloatForKey:(nonnull NSString *)key default:(CGFloat)defaultValue;

- (NSTimeInterval)asTimeinterval;
- (NSTimeInterval)timeintervalForKey:(nonnull NSString *)key;

- (nonnull NSString *)asString;
- (nonnull NSString *)stringForKey:(nonnull NSString *)key;
- (nonnull NSString *)stringForKey:(nonnull NSString *)key default:(nonnull NSString *)defaultValue;

- (nonnull UIColor *)asColor;
- (nonnull UIColor *)colorForKey:(nonnull NSString *)key;
- (nonnull UIColor *)colorForKey:(nonnull NSString *)key default:(nonnull UIColor *)defaultValue;

- (nonnull SDCBrush *)asBrush;
- (nonnull SDCBrush *)brushForKey:(nonnull NSString *)key;
- (nonnull SDCBrush *)brushForKey:(nonnull NSString *)key default:(nonnull SDCBrush *)defaultValue;

- (SDCFloatWithUnit)asFloatWithUnit;
- (SDCFloatWithUnit)floatWithUnitForKey:(nonnull NSString *)key;
- (SDCFloatWithUnit)floatWithUnitForKey:(nonnull NSString *)key
                                default:(SDCFloatWithUnit)defaultValue;

- (SDCPointWithUnit)asPointWithUnit;
- (SDCPointWithUnit)pointWithUnitForKey:(nonnull NSString *)key;
- (SDCPointWithUnit)pointWithUnitForKey:(nonnull NSString *)key
                                default:(SDCPointWithUnit)defaultValue;

- (SDCMarginsWithUnit)asMarginsWithUnit;
- (SDCMarginsWithUnit)marginsWithUnitForKey:(nonnull NSString *)key;
- (SDCMarginsWithUnit)marginsWithUnitForKey:(nonnull NSString *)key
                                    default:(SDCMarginsWithUnit)defaultValue;

- (nonnull SDCJSONValue *)asArray;
- (nonnull SDCJSONValue *)arrayForKey:(nonnull NSString *)key;
- (nonnull SDCJSONValue *)arrayForKey:(nonnull NSString *)key
                              default:(nonnull SDCJSONValue *)defaultValue;
- (NSUInteger)count;
- (nonnull SDCJSONValue *)JSONValueAtIndex:(NSUInteger)index;

- (nonnull SDCJSONValue *)asObject;
- (nonnull SDCJSONValue *)objectForKey:(nonnull NSString *)key;
- (nonnull SDCJSONValue *)objectForKey:(nonnull NSString *)key
                               default:(nonnull SDCJSONValue *)defaultValue;
- (BOOL)containsKey:(nonnull NSString *)key;
- (nonnull NSSet<NSString *> *)keys;

- (void)removeKeys:(nonnull NSSet<NSString *> *)keysToRemove;

- (BOOL)containsArrayWithKey:(nonnull NSString *)key;
- (BOOL)containsObjectWithKey:(nonnull NSString *)key;
- (void)renameKey:(nonnull NSString *)originalKeyName
    targetKeyName:(nonnull NSString *)targetKeyName;

@end

NS_ASSUME_NONNULL_END
